@@ -26,7 +26,7 @@ def parse():
         help='Send output to the given log file')
     parser.add_argument(
         '--log-level',
-        default='info',
+        choices=['debug', 'info', 'warning', 'error'],
         help='Log level to use (default: info)')
     parser.add_argument(
         '--version',
