@@ -41,7 +41,8 @@ def get_consumed_read_units_percent(table_name, gsi_name, time_frame=300):
     consumed_read_units_percent = int(
         math.ceil(
             float(consumed_read_units) /
-            float(get_provisioned_read_units(table_name, gsi_name)) * 100))
+            float(dynamodb.get_provisioned_gsi_read_units(
+                table_name, gsi_name)) * 100))
 
     logger.info('{0} - GSI: {1} - Consumed read units: {2:d}%'.format(
         table_name, gsi_name, consumed_read_units_percent))
@@ -81,52 +82,9 @@ def get_consumed_write_units_percent(table_name, gsi_name, time_frame=300):
     consumed_write_units_percent = int(
         math.ceil(
             float(consumed_write_units) /
-            float(get_provisioned_write_units(table_name, gsi_name)) * 100))
+            float(dynamodb.get_provisioned_gsi_write_units(
+                table_name, gsi_name)) * 100))
 
     logger.info('{0} - GSI: {1} - Consumed write units: {2:d}%'.format(
         table_name, gsi_name, consumed_write_units_percent))
     return consumed_write_units_percent
-
-
-def get_provisioned_read_units(table_name, gsi_name):
-    """ Returns the number of provisioned read units for the table
-
-    :type table_name: str
-    :param table_name: Name of the DynamoDB table
-    :type gsi_name: str
-    :param gsi_name: Name of the GSI
-    :returns: int -- Number of read units
-    """
-    desc = dynamodb.describe_table(table_name)
-    for gsi in desc[u'Table'][u'GlobalSecondaryIndexes']:
-        if gsi[u'IndexName'] == gsi_name:
-            read_units = int(
-                gsi[u'ProvisionedThroughput'][u'ReadCapacityUnits'])
-            break
-
-    logger.debug(
-        '{0} - GSI: {1} - Currently provisioned read units: {2:d}'.format(
-            table_name, gsi_name, read_units))
-    return read_units
-
-
-def get_provisioned_write_units(table_name, gsi_name):
-    """ Returns the number of provisioned write units for the table
-
-    :type table_name: str
-    :param table_name: Name of the DynamoDB table
-    :type gsi_name: str
-    :param gsi_name: Name of the GSI
-    :returns: int -- Number of write units
-    """
-    desc = dynamodb.describe_table(table_name)
-    for gsi in desc[u'Table'][u'GlobalSecondaryIndexes']:
-        if gsi[u'IndexName'] == gsi_name:
-            write_units = int(
-                gsi[u'ProvisionedThroughput'][u'WriteCapacityUnits'])
-            break
-
-    logger.debug(
-        '{0} - GSI: {1} - Currently povisioned write units: {2:d}'.format(
-            table_name, gsi_name, write_units))
-    return write_units
